@@ -1,8 +1,9 @@
-# $Id: Align.pm,v 1.9 2000/01/09 09:41:00 mgjv Exp $
+# $Id: Align.pm,v 1.12 2000/02/28 23:29:38 mgjv Exp $
 
 package GD::Text::Align;
 
-$GD::Text::Align::VERSION = '0.61';
+$GD::Text::Align::VERSION = 
+	(q($Revision: 1.12 $) =~ /\s([\d.]+)/ ? $1 : "0.0");
 
 =head1 NAME
 
@@ -50,9 +51,7 @@ use GD;
 use GD::Text;
 use Carp;
 
-@GD::Text::Align::ISA = qw( GD::Text );
-
-my $ERROR;
+@GD::Text::Align::ISA = qw(GD::Text);
 
 =head2 GD::Text::Align->new($gd_object, attrib => value, ...)
 
@@ -306,8 +305,8 @@ sub _align_builtin
 
 	($x, $y) = ($y, -$x) if ($self->_builtin_up);
 
-	$self->{x} = $x;
-	$self->{y} = $y;
+	$self->{'x'} = $x;
+	$self->{'y'} = $y;
 
 	return 1;
 }
@@ -350,8 +349,8 @@ sub _align_ttf
 		#/^base/   and $y = $y;
 	}
 
-	$self->{x} = $x;
-	$self->{y} = $y;
+	$self->{'x'} = $x;
+	$self->{'y'} = $y;
 
 	return 1;
 }
@@ -384,13 +383,13 @@ sub draw
 		if ($self->_builtin_up)
 		{
 			$self->{gd}->stringUp($self->{font}, 
-				$self->{x}, $self->{y},
+				$self->{'x'}, $self->{'y'},
 				$self->{text}, $self->{colour});
 		}
 		else
 		{
 			$self->{gd}->string($self->{font}, 
-				$self->{x}, $self->{y},
+				$self->{'x'}, $self->{'y'},
 				$self->{text}, $self->{colour});
 		}
 	}
@@ -398,7 +397,7 @@ sub draw
 	{
 		$self->{gd}->stringTTF($self->{colour}, 
 			$self->{font}, $self->{ptsize},
-			$self->{angle}, $self->{x}, $self->{y}, $self->{text});
+			$self->{angle}, $self->{'x'}, $self->{'y'}, $self->{text});
 	}
 	else
 	{
@@ -440,19 +439,19 @@ sub bounding_box
 		if ($self->_builtin_up)
 		{
 			return (
-				$self->{x} + $self->{height}, $self->{y},
-				$self->{x} + $self->{height}, $self->{y} - $self->{width},
-				$self->{x}                  , $self->{y} - $self->{width},
-				$self->{x}                  , $self->{y},
+				$self->{'x'} + $self->{height}, $self->{'y'},
+				$self->{'x'} + $self->{height}, $self->{'y'} - $self->{width},
+				$self->{'x'}                  , $self->{'y'} - $self->{width},
+				$self->{'x'}                  , $self->{'y'},
 			)
 		}
 		else
 		{
 			return (
-				$self->{x}                 , $self->{y} + $self->{height},
-				$self->{x} + $self->{width}, $self->{y} + $self->{height},
-				$self->{x} + $self->{width}, $self->{y},
-				$self->{x}                 , $self->{y},
+				$self->{'x'}                 , $self->{'y'} + $self->{height},
+				$self->{'x'} + $self->{width}, $self->{'y'} + $self->{height},
+				$self->{'x'} + $self->{width}, $self->{'y'},
+				$self->{'x'}                 , $self->{'y'},
 			)
 		}
 	}
@@ -460,7 +459,7 @@ sub bounding_box
 	{
 		return GD::Image->stringTTF($self->{colour}, 
 			$self->{font}, $self->{ptsize},
-			$self->{angle}, $self->{x}, $self->{y}, $self->{text});
+			$self->{angle}, $self->{'x'}, $self->{'y'}, $self->{text});
 	}
 	else
 	{
