@@ -1,8 +1,9 @@
-# $Id: Wrap.pm,v 1.10 2000/01/09 10:08:18 mgjv Exp $
+# $Id: Wrap.pm,v 1.12 2000/02/28 23:29:38 mgjv Exp $
 
 package GD::Text::Wrap;
 
-$GD::Text::Wrap::VERSION = '0.63';
+$GD::Text::Wrap::VERSION =
+	(q($Revision: 1.12 $) =~ /\s([\d.]+)/ ? $1 : "0.0");
 
 =head1 NAME
 
@@ -94,7 +95,9 @@ sub _init
 	$self->{render} = GD::Text::Align->new($self->{gd}, text => 'Foo');
 	croak "Cannot allocate GD::Text::Align object" unless $self->{render};
 
-	$self->set($_, $attribs{$_}) foreach (keys %attribs);
+	# XXX 5.004_04 doesn't like foreach as a modifier
+	#$self->set($_, $attribs{$_}) foreach (keys %attribs);
+	foreach (keys %attribs) { $self->set($_, $attribs{$_}) };
 	# XXX SET DEFAULTS
 
     $self->set(
@@ -328,7 +331,7 @@ sub _draw_justified_line
 
 
 #
-# Delegate all the woother methods to the GD::Text::Align method
+# Delegate all the other methods to the GD::Text::Align method
 use vars qw($AUTOLOAD);
 sub AUTOLOAD
 {
